@@ -47,7 +47,7 @@ import {
   V1ServiceAccount,
   V1ServiceList,
   Watch,
-  V1CustomResourceDefinition,
+  V1CustomResourceDefinition, V1ValidatingWebhookConfiguration,
 } from '@kubernetes/client-node'
 import { Cluster } from '@kubernetes/client-node/dist/config_types'
 import axios, { AxiosRequestConfig } from 'axios'
@@ -62,7 +62,7 @@ import { CHE_CLUSTER_API_GROUP, CHE_CLUSTER_API_VERSION_V1, CHE_CLUSTER_API_VERS
 import { getClusterClientCommand, getImageNameAndTag, isCheClusterAPIV1, isWebhookAvailabilityError, newError, safeLoadFromYamlFile, sleep } from '../util'
 import { ChectlContext } from './context'
 import { V1Certificate } from './types/cert-manager'
-import { CatalogSource, ClusterServiceVersion, ClusterServiceVersionList, InstallPlan, OperatorGroup, Subscription } from './types/olm'
+import { CatalogSource, ClusterServiceVersion, ClusterServiceVersionList, InstallPlan, Subscription } from './types/olm'
 
 const AWAIT_TIMEOUT_S = 30
 
@@ -260,11 +260,6 @@ export class KubeHelper {
     }
   }
 
-  async createRoleFromFile(filePath: string, namespace: string): Promise<void> {
-    const yamlRole = this.safeLoadFromYamlFile(filePath) as V1Role
-    return this.createRole(yamlRole, namespace)
-  }
-
   async replaceRole(yamlRole: V1Role, namespace: string): Promise<void> {
     const k8sRbacAuthApi = this.kubeConfig.makeApiClient(RbacAuthorizationV1Api)
     try {
@@ -365,6 +360,38 @@ export class KubeHelper {
     }
   }
 
+  async isValidatingWebhookConfigurationExists(name: string): Promise<boolean> {
+    const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
+    try {
+      await k8sAdmissionApi.readValidatingWebhookConfiguration(name)
+      return true
+    } catch (e: any) {
+      if (e.response && e.response.statusCode === 404) {
+        return false
+      }
+
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async replaceValidatingWebhookConfiguration(name: string, webhook: V1ValidatingWebhookConfiguration): Promise<void> {
+    const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
+    try {
+      await k8sAdmissionApi.replaceValidatingWebhookConfiguration(name, webhook)
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
+  async createValidatingWebhookConfiguration(webhook: V1ValidatingWebhookConfiguration): Promise<void> {
+    const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
+    try {
+      await k8sAdmissionApi.createValidatingWebhookConfiguration(webhook)
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
   async deleteValidatingWebhookConfiguration(name: string): Promise<void> {
     const k8sAdmissionApi = this.kubeConfig.makeApiClient(AdmissionregistrationV1Api)
     try {
@@ -421,11 +448,6 @@ export class KubeHelper {
     }
   }
 
-  async createRoleBindingFromFile(filePath: string, namespace: string): Promise<void> {
-    const yamlRoleBinding = this.safeLoadFromYamlFile(filePath) as V1RoleBinding
-    return this.createRoleBinding(yamlRoleBinding, namespace)
-  }
-
   async replaceRoleBinding(yamlRoleBinding: V1RoleBinding, namespace: string): Promise<void> {
     const k8sRbacAuthApi = this.kubeConfig.makeApiClient(RbacAuthorizationV1Api)
     try {
@@ -1065,10 +1087,10 @@ export class KubeHelper {
           if (!cheClusterCR.spec.networking?.tlsSecretName) {
             merge(cheClusterCR, { spec: { networking: { tlsSecretName: CHE_TLS_SECRET_NAME } }  })
           }
-        }
 
-        if (flags.domain) {
-          merge(cheClusterCR, { spec: { networking: { domain: flags.domain } }  })
+          if (flags.domain) {
+            merge(cheClusterCR, { spec: { networking: { domain: flags.domain } }  })
+          }
         }
 
         const pluginRegistryUrl = flags['plugin-registry-url']
@@ -1317,7 +1339,7 @@ export class KubeHelper {
     }
   }
 
-  async IsCatalogSourceExists(name: string, namespace: string): Promise<boolean> {
+  async isCatalogSourceExists(name: string, namespace: string): Promise<boolean> {
     const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
     try {
       await customObjectsApi.getNamespacedCustomObject('operators.coreos.com', 'v1alpha1', namespace, 'catalogsources', name)
@@ -1331,6 +1353,16 @@ export class KubeHelper {
     }
   }
 
+  async listCatalogSources(namespace: string, labelSelector: string): Promise<any[]> {
+    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
+    try {
+      const {body} = await customObjectsApi.listNamespacedCustomObject('operators.coreos.com', 'v1alpha1', namespace, 'catalogsources', undefined, undefined, undefined, labelSelector)
+      return (body as any).items
+    } catch (e: any) {
+      throw this.wrapK8sClientError(e)
+    }
+  }
+
   async listOAuthClientBySelector(selector: string): Promise<any[]> {
     const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
     try {
@@ -1372,10 +1404,10 @@ export class KubeHelper {
     return catalogSource
   }
 
-  async createCatalogSource(catalogSource: CatalogSource) {
+  async createCatalogSource(catalogSource: CatalogSource, namespace: string) {
     const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
     try {
-      const namespace = catalogSource.metadata.namespace!
+      delete catalogSource.metadata?.namespace
       const { body } = await customObjectsApi.createNamespacedCustomObject('operators.coreos.com', 'v1alpha1', namespace, 'catalogsources', catalogSource)
       return body
     } catch (e: any) {
@@ -1416,54 +1448,6 @@ export class KubeHelper {
     }
   }
 
-  async getOperatorGroup(name: string, namespace: string): Promise<OperatorGroup | undefined> {
-    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-    try {
-      const response = await customObjectsApi.getNamespacedCustomObject('operators.coreos.com', 'v1', namespace, 'operatorgroups', name)
-      if (response && response.body) {
-        return response.body as OperatorGroup
-      }
-    } catch (error: any) {
-      if (error.response && error.response.statusCode === 404) {
-        return
-      }
-      throw this.wrapK8sClientError(error)
-    }
-  }
-
-  async createOperatorGroup(name: string, namespace: string) {
-    const operatorGroup: OperatorGroup = {
-      apiVersion: 'operators.coreos.com/v1',
-      kind: 'OperatorGroup',
-      metadata: {
-        name: name,
-        namespace,
-      },
-      spec: {
-        targetNamespaces: [],
-      },
-    }
-
-    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-    try {
-      const { body } = await customObjectsApi.createNamespacedCustomObject('operators.coreos.com', 'v1', namespace, 'operatorgroups', operatorGroup)
-      return body
-    } catch (e: any) {
-      throw this.wrapK8sClientError(e)
-    }
-  }
-
-  async deleteOperatorGroup(name: string, namespace: string): Promise<void> {
-    const customObjectsApi = this.kubeConfig.makeApiClient(CustomObjectsApi)
-    try {
-      await customObjectsApi.deleteNamespacedCustomObject('operators.coreos.com', 'v1', namespace, 'operatorgroups', name)
-    } catch (e: any) {
-      if (e.response.statusCode !== 404) {
-        throw this.wrapK8sClientError(e)
-      }
-    }
-  }
-
   async createOperatorSubscription(subscription: Subscription) {
     const namespace: string = subscription.metadata.namespace!
 
