@@ -28,7 +28,7 @@ import {
 } from '../../tasks/installers/common-tasks'
 import { ApiTasks } from '../../tasks/platforms/api'
 import { PlatformTasks } from '../../tasks/platforms/platform'
-import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getWarnVersionFlagMsg, isKubernetesPlatformFamily, isOpenshiftPlatformFamily, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
+import { askForChectlUpdateIfNeeded, getCommandSuccessMessage, getWarnVersionFlagMsg, notifyCommandCompletedSuccessfully, wrapCommandError } from '../../util'
 import { InstallerTasks } from '../../tasks/installers/installer'
 
 export default class Deploy extends Command {
@@ -128,6 +128,7 @@ export default class Deploy extends Command {
                     By default this flag is enabled.
                     This parameter is used only when the installer is 'olm'.`,
       allowNo: true,
+      default: true,
       exclusive: ['starting-csv'],
     }),
     'starting-csv': flags.string({
@@ -152,14 +153,20 @@ export default class Deploy extends Command {
                     Catalog source will be applied to the namespace with Che operator.
                     Also you need define 'olm-channel' name and 'package-manifest-name'.
                     This parameter is used only when the installer is the 'olm'.`,
+      exclusive: ['catalog-source-name', 'catalog-source-namespace'],
+      dependsOn: ['olm-channel', 'package-manifest-name'],
     }),
     'catalog-source-name': string({
       description: `OLM catalog source to install Red Hat OpenShift Dev Spaces operator.
                     This parameter is used only when the installer is the 'olm'.`,
+      dependsOn: ['catalog-source-namespace'],
+      exclusive: ['catalog-source-yaml'],
     }),
     'catalog-source-namespace': string({
       description: `Namespace for OLM catalog source to install Red Hat OpenShift Dev Spaces operator.
                     This parameter is used only when the installer is the 'olm'.`,
+      dependsOn: ['catalog-source-name'],
+      exclusive: ['catalog-source-yaml'],
     }),
     'cluster-monitoring': boolean({
       default: false,
@@ -176,19 +183,18 @@ export default class Deploy extends Command {
     [DEPLOY_VERSION_KEY]: cheDeployVersion,
   }
 
-  async setPlaformDefaults(flags: any, _ctx: any): Promise<void> {
-    if (flags['self-signed-cert']) {
-      this.warn('"self-signed-cert" flag is deprecated and has no effect. Autodetection is used instead.')
-    }
-
-    if (!flags.installer) {
-      await setDefaultInstaller(flags)
-      cli.info(`› Installer type is set to: '${flags.installer}'`)
-    }
-  }
-
   private checkCompatibility(flags: any) {
-    if (flags.installer === 'operator' && flags[CHE_OPERATOR_CR_YAML_KEY]) {
+    const ctx = ChectlContext.get()
+
+    if (flags.installer === 'operator' && ctx[ChectlContext.IS_OPENSHIFT]) {
+      cli.error('--installer=operator is not supported for OpenShift platform.')
+    }
+
+    if (flags.installer === 'olm' && !ctx[ChectlContext.IS_OPENSHIFT]) {
+      cli.error('--installer=operator is not supported for Kubernetes platform.')
+    }
+
+    if (flags[CHE_OPERATOR_CR_YAML_KEY]) {
       const ignoredFlags = []
       flags['plugin-registry-url'] && ignoredFlags.push('--plugin-registry-url')
       flags['devfile-registry-url'] && ignoredFlags.push('--devfile-registry-url')
@@ -203,48 +209,32 @@ export default class Deploy extends Command {
       }
     }
 
-    if (flags.domain && !flags[CHE_OPERATOR_CR_YAML_KEY] && isOpenshiftPlatformFamily(flags.platform)) {
-      this.warn('"--domain" flag is ignored for Openshift family infrastructures. It should be done on the cluster level.')
+    if (flags.domain && ctx[ChectlContext.IS_OPENSHIFT]) {
+      this.warn('--domain flag is ignored for OpenShift platform.')
     }
 
-    if (flags.installer === 'olm') {
-      // OLM installer only checks
-      if (isKubernetesPlatformFamily(flags.platform)) {
-        this.error(`🛑 The specified installer ${flags.installer} does not support Kubernentes`)
-      }
-
-      if (flags[OLM.CATALOG_SOURCE_NAME] && flags[OLM.CATALOG_SOURCE_YAML]) {
-        this.error(`should be provided only one argument: "${OLM.CATALOG_SOURCE_NAME}" or "${OLM.CATALOG_SOURCE_YAML}"`)
-      }
-
-      if (!flags[OLM.PACKAGE_MANIFEST_NAME] && flags[OLM.CATALOG_SOURCE_YAML]) {
-        this.error(`you need to define "${OLM.PACKAGE_MANIFEST_NAME}" flag to use "${OLM.CATALOG_SOURCE_YAML}".`)
-      }
-      if (!flags[OLM.CHANNEL] && flags[OLM.CATALOG_SOURCE_YAML]) {
-        this.error(`you need to define "${OLM.CHANNEL}" flag to use "${OLM.CATALOG_SOURCE_YAML}".`)
-      }
-    } else {
+    if (!ctx[ChectlContext.IS_OPENSHIFT]) {
       // Not OLM installer
       if (flags[OLM.STARTING_CSV]) {
-        this.error(`"${OLM.STARTING_CSV}" flag should be used only with "olm" installer.`)
+        this.error(`"${OLM.STARTING_CSV}" flag should be used only for OpenShift platform.`)
       }
       if (flags[OLM.CATALOG_SOURCE_YAML]) {
-        this.error(`"${OLM.CATALOG_SOURCE_YAML}" flag should be used only with "olm" installer.`)
+        this.error(`"${OLM.CATALOG_SOURCE_YAML}" flag should be used only for OpenShift platform.`)
       }
       if (flags[OLM.CHANNEL]) {
-        this.error(`"${OLM.CHANNEL}" flag should be used only with "olm" installer.`)
+        this.error(`"${OLM.CHANNEL}" flag should be used only for OpenShift platform.`)
       }
       if (flags[OLM.PACKAGE_MANIFEST_NAME]) {
-        this.error(`"${OLM.PACKAGE_MANIFEST_NAME}" flag should be used only with "olm" installer.`)
+        this.error(`"${OLM.PACKAGE_MANIFEST_NAME}" flag should be used only for OpenShift platform.`)
       }
       if (flags[OLM.CATALOG_SOURCE_NAME]) {
-        this.error(`"${OLM.CATALOG_SOURCE_NAME}" flag should be used only with "olm" installer.`)
+        this.error(`"${OLM.CATALOG_SOURCE_NAME}" flag should be used only for OpenShift platform.`)
       }
       if (flags[OLM.CATALOG_SOURCE_NAMESPACE]) {
-        this.error(`"${OLM.CATALOG_SOURCE_NAMESPACE}" flag should be used only with "olm" installer.`)
+        this.error(`"${OLM.CATALOG_SOURCE_NAMESPACE}" flag should be used only for OpenShift platform.`)
       }
-      if (flags['cluster-monitoring'] && flags.platform !== 'openshift') {
-        this.error('"cluster-monitoring" flag should be used only with "olm" installer and "openshift" platform.')
+      if (flags['cluster-monitoring']) {
+        this.error('"cluster-monitoring" flag should be used only for OpenShift platform.')
       }
     }
   }
@@ -263,7 +253,6 @@ export default class Deploy extends Command {
       this.exit(1)
     }
 
-    await this.setPlaformDefaults(flags, ctx)
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Deploy.id, flags })
 
     const dexTasks = new DexTasks(flags)
@@ -293,7 +282,10 @@ export default class Deploy extends Command {
     if (flags.platform === 'minikube') {
       installTasks.add(dexTasks.getInstallTasks())
     }
-    installTasks.add(await installerTasks.installTasks(flags, this))
+    installTasks.add({
+      title: 'Deploy Red Hat OpenShift Dev Spaces',
+      task: () => new Listr(installerTasks.deployTasks(flags), ctx.listrOptions),
+    })
 
     // Post Install Checks
     const postInstallTasks = new Listr([
@@ -350,7 +342,7 @@ export default class Deploy extends Command {
 function ensureOIDCProviderInstalled(flags: any): Listr.ListrTask {
   return {
     title: 'Check if OIDC Provider installed',
-    enabled: ctx => !flags['skip-oidc-provider-check'] && isKubernetesPlatformFamily(flags.platform) && !ctx.isCheDeployed,
+    enabled: ctx => !flags['skip-oidc-provider-check'] && !ctx[ChectlContext.IS_OPENSHIFT] && !ctx.isCheDeployed,
     skip: () => {
       if (flags.platform === 'minikube') {
         return 'Dex will be automatically installed as OIDC Identity Provider'
@@ -384,24 +376,3 @@ function ensureOIDCProviderInstalled(flags: any): Listr.ListrTask {
     },
   }
 }
-
-/**
- * Sets default installer which is `olm` for OpenShift 4 with stable version of dsc
- * and `operator` for other cases.
- */
-export async function setDefaultInstaller(flags: any): Promise<void> {
-  const kubeHelper = new KubeHelper(flags)
-
-  const isOlmPreinstalled = await kubeHelper.isPreInstalledOLM()
-  if ((flags[OLM.CATALOG_SOURCE_NAME] || flags[OLM.CATALOG_SOURCE_YAML]) && isOlmPreinstalled) {
-    flags.installer = 'olm'
-    return
-  }
-
-  const ctx = ChectlContext.get()
-  if (flags.platform === 'openshift' && ctx[ChectlContext.IS_OPENSHIFT] && isOlmPreinstalled) {
-    flags.installer = 'olm'
-  } else {
-    flags.installer = 'operator'
-  }
-}
