@@ -34,8 +34,8 @@ import {
 import {
   DEFAULT_ANALYTIC_HOOK_NAME,
   DEFAULT_CHE_NAMESPACE,
-  DEFAULT_CHE_OPERATOR_IMAGE_NAME,
-  NEXT_TAG,
+  OPERATOR_IMAGE_NAME,
+  OPERATOR_IMAGE_NEXT_TAG,
 } from '../../constants'
 import {getPrintHighlightedMessagesTask} from '../../tasks/installers/common-tasks'
 import {InstallerTasks} from '../../tasks/installers/installer'
@@ -110,9 +110,12 @@ export default class Update extends Command {
     }
 
     await this.setDomainFlag(flags)
+
     if (!flags.installer) {
-      await this.setDefaultInstaller(flags)
-      cli.info(`› Installer type is set to: '${flags.installer}'`)
+      flags.installer = await this.getCurrentInstaller(flags)
+    }
+    if (flags.installer === 'operator' && ctx[ChectlContext.IS_OPENSHIFT]) {
+      cli.error('--installer=operator is not supported for OpenShift platform.')
     }
 
     await this.config.runHook(DEFAULT_ANALYTIC_HOOK_NAME, { command: Update.id, flags })
@@ -123,13 +126,16 @@ export default class Update extends Command {
     const apiTasks = new ApiTasks()
     const preUpdateTasks = new Listr([], ctx.listrOptions)
     preUpdateTasks.add(apiTasks.testApiTasks(flags))
-    preUpdateTasks.add(installerTasks.preUpdateTasks(flags, this))
+    preUpdateTasks.add({
+      title: 'Preflight check',
+      task: () => new Listr(installerTasks.preUpdateTasks(flags), ctx.listrOptions),
+    })
 
     // update tasks
     const updateTasks = new Listr([], ctx.listrOptions)
     updateTasks.add({
-      title: 'Updating...',
-      task: () => new Listr(installerTasks.updateTasks(flags, this)),
+      title: 'Update Red Hat OpenShift Dev Spaces',
+      task: () => new Listr(installerTasks.updateTasks(flags), ctx.listrOptions),
     })
 
     // post update tasks
@@ -139,7 +145,7 @@ export default class Update extends Command {
     try {
       await preUpdateTasks.run(ctx)
 
-      if (flags.installer === 'operator') {
+      if (!ctx[ChectlContext.IS_OPENSHIFT]) {
         if (!await this.checkAbilityToUpdateCheOperatorAndAskUser(flags)) {
           // Exit
           return
@@ -169,12 +175,12 @@ export default class Update extends Command {
     cli.info(`Existing Red Hat OpenShift Dev Spaces operator: ${ctx.deployedCheOperatorImage}`)
     cli.info(`New Red Hat OpenShift Dev Spaces operator     : ${ctx.newCheOperatorImage}`)
 
-    if (ctx.deployedCheOperatorImageName === DEFAULT_CHE_OPERATOR_IMAGE_NAME && ctx.newCheOperatorImageName === DEFAULT_CHE_OPERATOR_IMAGE_NAME) {
+    if (ctx.deployedCheOperatorImageName === OPERATOR_IMAGE_NAME && ctx.newCheOperatorImageName === OPERATOR_IMAGE_NAME) {
       // Official images
 
       if (ctx.deployedCheOperatorImage === ctx.newCheOperatorImage) {
-        if (ctx.newCheOperatorImageTag === NEXT_TAG) {
-          cli.info(`Updating current Red Hat OpenShift Dev Spaces ${NEXT_TAG} version to a new one.`)
+        if (ctx.newCheOperatorImageTag === OPERATOR_IMAGE_NEXT_TAG) {
+          cli.info(`Updating current Red Hat OpenShift Dev Spaces ${OPERATOR_IMAGE_NEXT_TAG} version to a new one.`)
           return true
         }
 
@@ -192,10 +198,10 @@ export default class Update extends Command {
         // Upgrade
 
         const currentChectlVersion = getProjectVersion()
-        if (!ctx.isDevVersion && (ctx.newCheOperatorImageTag === NEXT_TAG || semver.lt(currentChectlVersion, ctx.newCheOperatorImageTag))) {
+        if (!ctx.isDevVersion && (ctx.newCheOperatorImageTag === OPERATOR_IMAGE_NEXT_TAG || semver.lt(currentChectlVersion, ctx.newCheOperatorImageTag))) {
           // Upgrade is not allowed
-          if (ctx.newCheOperatorImageTag === NEXT_TAG) {
-            cli.warn(`Stable ${getProjectName()} cannot update stable Red Hat OpenShift Dev Spaces to ${NEXT_TAG} version`)
+          if (ctx.newCheOperatorImageTag === OPERATOR_IMAGE_NEXT_TAG) {
+            cli.warn(`Stable ${getProjectName()} cannot update stable Red Hat OpenShift Dev Spaces to ${OPERATOR_IMAGE_NEXT_TAG} version`)
           } else {
             cli.warn(`It is not possible to update Red Hat OpenShift Dev Spaces to a newer version using the current '${currentChectlVersion}' version of dsc. Please, update '${getProjectName()}' to a newer version using command '${getProjectName()} update' and then try again.`)
           }
@@ -203,8 +209,8 @@ export default class Update extends Command {
         }
 
         // Upgrade allowed
-        if (ctx.newCheOperatorImageTag === NEXT_TAG) {
-          cli.info(`You are going to update Red Hat OpenShift Dev Spaces ${ctx.deployedCheOperatorImageTag} to ${NEXT_TAG} version.`)
+        if (ctx.newCheOperatorImageTag === OPERATOR_IMAGE_NEXT_TAG) {
+          cli.info(`You are going to update Red Hat OpenShift Dev Spaces ${ctx.deployedCheOperatorImageTag} to ${OPERATOR_IMAGE_NEXT_TAG} version.`)
         } else {
           cli.info(`You are going to update Red Hat OpenShift Dev Spaces ${ctx.deployedCheOperatorImageTag} to ${ctx.newCheOperatorImageTag}`)
         }
@@ -219,12 +225,12 @@ export default class Update extends Command {
       if (ctx.deployedCheOperatorImage === ctx.newCheOperatorImage) {
         // Despite the image is the same it could be updated image, replace anyway.
         cli.info(`You are going to replace Red Hat OpenShift Dev Spaces operator image ${ctx.newCheOperatorImage}.`)
-      } else if (ctx.deployedCheOperatorImageName !== DEFAULT_CHE_OPERATOR_IMAGE_NAME && ctx.newCheOperatorImageName !== DEFAULT_CHE_OPERATOR_IMAGE_NAME) {
+      } else if (ctx.deployedCheOperatorImageName !== OPERATOR_IMAGE_NAME && ctx.newCheOperatorImageName !== OPERATOR_IMAGE_NAME) {
         // Both images are custom
         cli.info(`You are going to update ${ctx.deployedCheOperatorImage} to ${ctx.newCheOperatorImage}`)
       } else {
         // One of the images is offical
-        if (ctx.deployedCheOperatorImageName === DEFAULT_CHE_OPERATOR_IMAGE_NAME) {
+        if (ctx.deployedCheOperatorImageName === OPERATOR_IMAGE_NAME) {
           // Update from offical to custom image
           cli.info(`You are going to update official ${ctx.deployedCheOperatorImage} image with user provided one: ${ctx.newCheOperatorImage}`)
         } else { // ctx.newCheOperatorImageName === DEFAULT_CHE_OPERATOR_IMAGE_NAME
@@ -273,7 +279,7 @@ export default class Update extends Command {
     // if oldTag is NEXT_TAG it is downgrade
     // otherwise just compare new and old tags
     // Note, that semver lib doesn't handle text tags and throws an error in case NEXT_TAG is provided for comparation.
-    return newTag === NEXT_TAG || (oldTag !== NEXT_TAG && isUpdate)
+    return newTag === OPERATOR_IMAGE_NEXT_TAG || (oldTag !== OPERATOR_IMAGE_NEXT_TAG && isUpdate)
   }
 
   /**
@@ -287,15 +293,11 @@ export default class Update extends Command {
     }
   }
 
-  /**
-   * Sets installer type depending on the previous installation.
-   */
-  private async setDefaultInstaller(flags: any): Promise<void> {
+  private async getCurrentInstaller(flags: any): Promise<string> {
     const cheHelper = new CheHelper(flags)
     if (await cheHelper.findCheOperatorSubscription(flags.chenamespace)) {
-      flags.installer = 'olm'
-    } else {
-      flags.installer = 'operator'
+      return 'olm'
     }
+    return 'operator'
   }
 }
