@@ -18,6 +18,7 @@ import {
   V1RoleBinding,
   V1Service,
   V1CustomResourceDefinition,
+  V1ValidatingWebhookConfiguration,
 } from '@kubernetes/client-node'
 import {cli} from 'cli-ux'
 import * as fs from 'fs'
@@ -26,7 +27,13 @@ import * as path from 'path'
 import * as yaml from 'js-yaml'
 import {ChectlContext} from '../../api/context'
 import {KubeHelper} from '../../api/kube'
-import {CHE_CLUSTER_CRD, CHE_OPERATOR_SELECTOR, OPERATOR_DEPLOYMENT_NAME} from '../../constants'
+import {
+  CHE_CLUSTER_API_GROUP,
+  CHE_CLUSTER_API_VERSION_V2,
+  CHE_CLUSTER_CRD,
+  CHE_OPERATOR_SELECTOR,
+  OPERATOR_DEPLOYMENT_NAME,
+} from '../../constants'
 import {getImageNameAndTag, isCheClusterAPIV1, safeLoadFromYamlFile} from '../../util'
 import {KubeTasks} from '../kube'
 import {createEclipseCheClusterTask, patchingEclipseCheCluster} from './common-tasks'
@@ -34,11 +41,11 @@ import {V1Certificate} from '../../api/types/cert-manager'
 import {OpenShiftHelper} from '../../api/openshift'
 
 export class OperatorTasks {
+  private static readonly VALIDATING_WEBHOOK = 'org.eclipse.che'
   private static readonly WEBHOOK_SERVICE = 'devspaces-operator-service'
   private static readonly CERTIFICATE = 'devspaces-operator-serving-cert'
   private static readonly ISSUER = 'devspaces-operator-selfsigned-issuer'
   private static readonly SERVICE_ACCOUNT = 'devspaces-operator'
-  private static readonly DEVWORKSPACE_PREFIX = 'devworkspace-che'
   private static readonly CONSOLELINK = 'che'
 
   protected kh: KubeHelper
@@ -161,7 +168,7 @@ export class OperatorTasks {
   /**
    * Returns tasks list which perform preflight platform checks.
    */
-  async deployTasks(): Promise<Listr.ListrTask[]> {
+  deployTasks(): Listr.ListrTask<any>[] {
     const kube = new KubeHelper(this.flags)
     const kubeTasks = new KubeTasks(this.flags)
 
@@ -182,7 +189,6 @@ export class OperatorTasks {
       this.getCreateOrUpdateRolesAndBindingsTasks(false),
       {
         title: `Create Certificate ${OperatorTasks.CERTIFICATE}`,
-        enabled: ctx => !ctx[ChectlContext.IS_OPENSHIFT],
         task: async (ctx: any, task: any) => {
           const exists = await this.kh.isCertificateExists(OperatorTasks.CERTIFICATE, this.flags.chenamespace)
           if (exists) {
@@ -203,7 +209,6 @@ export class OperatorTasks {
       },
       {
         title: `Create Issuer ${OperatorTasks.ISSUER}`,
-        enabled: ctx => !ctx[ChectlContext.IS_OPENSHIFT],
         task: async (ctx: any, task: any) => {
           const exists = await this.kh.isIssuerExists(OperatorTasks.ISSUER, this.flags.chenamespace)
           if (exists) {
@@ -247,9 +252,7 @@ export class OperatorTasks {
             const crdPath = await this.getCRDPath()
             const crd = this.kh.safeLoadFromYamlFile(crdPath) as V1CustomResourceDefinition
             crd.spec.conversion!.webhook!.clientConfig!.service!.namespace = this.flags.chenamespace
-            if (!ctx[ChectlContext.IS_OPENSHIFT]) {
-              crd.metadata!.annotations!['cert-manager.io/inject-ca-from'] = `${this.flags.chenamespace}/devspaces-operator-serving-cert`
-            }
+            crd.metadata!.annotations!['cert-manager.io/inject-ca-from'] = `${this.flags.chenamespace}/devspaces-operator-serving-cert`
 
             await this.kh.createCrdFromFile(crd)
             task.title = `${task.title}...[OK: created]`
@@ -281,12 +284,31 @@ export class OperatorTasks {
         title: 'Operator pod bootstrap',
         task: () => kubeTasks.podStartTasks(CHE_OPERATOR_SELECTOR, this.flags.chenamespace),
       },
+      {
+        title: `Create ValidatingWebhookConfiguration ${OperatorTasks.VALIDATING_WEBHOOK}`,
+        task: async (ctx: any, task: any) => {
+          const exists = await this.kh.isValidatingWebhookConfigurationExists(OperatorTasks.VALIDATING_WEBHOOK)
+          if (exists) {
+            task.title = `${task.title}...[Exists]`
+          } else {
+            const webhookPath = this.getResourcePath('org.eclipse.che.ValidatingWebhookConfiguration.yaml')
+            if (fs.existsSync(webhookPath)) {
+              const webhook = this.kh.safeLoadFromYamlFile(webhookPath) as V1ValidatingWebhookConfiguration
+              webhook!.webhooks![0].clientConfig.service!.namespace = this.flags.chenamespace
+              await this.kh.createValidatingWebhookConfiguration(webhook)
+              task.title = `${task.title}...[OK: created]`
+            } else {
+              task.title = `${task.title}...[Not found]`
+            }
+          }
+        },
+      },
       createEclipseCheClusterTask(this.flags, kube),
     ]
   }
 
-  preUpdateTasks(): Listr {
-    return new Listr([
+  preUpdateTasks(): Listr.ListrTask<any>[] {
+    return [
       {
         title: 'Checking if operator deployment exists',
         task: async (ctx: any, task: any) => {
@@ -330,10 +352,10 @@ export class OperatorTasks {
           }
         },
       },
-    ])
+    ]
   }
 
-  updateTasks(): Array<Listr.ListrTask> {
+  updateTasks(): Listr.ListrTask<any>[] {
     return [
       {
         title: `Update ServiceAccount ${OperatorTasks.SERVICE_ACCOUNT}`,
@@ -352,7 +374,6 @@ export class OperatorTasks {
       this.getCreateOrUpdateRolesAndBindingsTasks(true),
       {
         title: `Update Certificate ${OperatorTasks.CERTIFICATE}`,
-        enabled: ctx => !ctx[ChectlContext.IS_OPENSHIFT],
         task: async (ctx: any, task: any) => {
           const yamlFilePath = this.getResourcePath('serving-cert.yaml')
           if (!fs.existsSync(yamlFilePath)) {
@@ -375,7 +396,6 @@ export class OperatorTasks {
       },
       {
         title: `Update Issuer ${OperatorTasks.ISSUER}`,
-        enabled: ctx => !ctx[ChectlContext.IS_OPENSHIFT],
         task: async (ctx: any, task: any) => {
           const yamlFilePath = this.getResourcePath('selfsigned-issuer.yaml')
           if (!fs.existsSync(yamlFilePath)) {
@@ -422,9 +442,7 @@ export class OperatorTasks {
           const crdPath = await this.getCRDPath()
           const crd = this.kh.safeLoadFromYamlFile(crdPath) as V1CustomResourceDefinition
           crd.spec.conversion!.webhook!.clientConfig!.service!.namespace = this.flags.chenamespace
-          if (!ctx[ChectlContext.IS_OPENSHIFT]) {
-            crd.metadata!.annotations!['cert-manager.io/inject-ca-from'] = `${this.flags.chenamespace}/devspaces-operator-serving-cert`
-          }
+          crd.metadata!.annotations!['cert-manager.io/inject-ca-from'] = `${this.flags.chenamespace}/devspaces-operator-serving-cert`
 
           if (existedCRD) {
             await this.kh.replaceCrdFromFile(crd)
@@ -464,6 +482,27 @@ export class OperatorTasks {
           await this.kh.waitLatestReplica(OPERATOR_DEPLOYMENT_NAME, this.flags.chenamespace)
         },
       },
+      {
+        title: `Update ValidatingWebhookConfiguration ${OperatorTasks.VALIDATING_WEBHOOK}`,
+        task: async (ctx: any, task: any) => {
+          const webhookPath = this.getResourcePath('org.eclipse.che.ValidatingWebhookConfiguration.yaml')
+          if (fs.existsSync(webhookPath)) {
+            const webhook = this.kh.safeLoadFromYamlFile(webhookPath) as V1ValidatingWebhookConfiguration
+            webhook!.webhooks![0].clientConfig.service!.namespace = this.flags.chenamespace
+
+            const exists = await this.kh.isValidatingWebhookConfigurationExists(OperatorTasks.VALIDATING_WEBHOOK)
+            if (exists) {
+              await this.kh.replaceValidatingWebhookConfiguration(OperatorTasks.VALIDATING_WEBHOOK, webhook)
+              task.title = `${task.title}...[Ok: updated]`
+            } else {
+              await this.kh.createValidatingWebhookConfiguration(webhook)
+              task.title = `${task.title}...[OK: created]`
+            }
+          } else {
+            task.title = `${task.title}...[Not found]`
+          }
+        },
+      },
       patchingEclipseCheCluster(this.flags, this.kh),
     ]
   }
@@ -471,62 +510,11 @@ export class OperatorTasks {
   /**
    * Returns list of tasks which remove Red Hat OpenShift Dev Spaces operator related resources
    */
-  getDeleteTasks(flags: any): ReadonlyArray<Listr.ListrTask> {
+  getDeleteCRsTasks(flags: any): ReadonlyArray<Listr.ListrTask> {
     const kh = new KubeHelper(flags)
     return [
       {
-        title: `Delete Issuer ${OperatorTasks.ISSUER}`,
-        task: async (_ctx: any, task: any) => {
-          try {
-            await kh.deleteIssuer(OperatorTasks.ISSUER, this.flags.chenamespace)
-            task.title = `${task.title}...[Ok]`
-          } catch (e: any) {
-            task.title = `${task.title}...[Failed: ${e.message}]`
-          }
-        },
-      },
-      {
-        title: `Delete Certificate ${OperatorTasks.CERTIFICATE}`,
-        task: async (_ctx: any, task: any) => {
-          try {
-            await kh.deleteCertificate(OperatorTasks.CERTIFICATE, this.flags.chenamespace)
-            task.title = `${task.title}...[Ok]`
-          } catch (e: any) {
-            task.title = `${task.title}...[Failed: ${e.message}]`
-          }
-        },
-      },
-      {
-        title: 'Delete OAuthClient',
-        enabled: (ctx: any) => ctx[ChectlContext.IS_OPENSHIFT],
-        task: async (_ctx: any, task: any) => {
-          try {
-            const checluster = await kh.getCheClusterV1(flags.chenamespace)
-            if (checluster) {
-              if (isCheClusterAPIV1(checluster)) {
-                if (checluster?.spec?.auth?.oAuthClientName) {
-                  await kh.deleteOAuthClient(checluster.spec.auth.oAuthClientName)
-                }
-              } else {
-                if (checluster?.spec?.networking?.auth?.oAuthClientName) {
-                  await kh.deleteOAuthClient(checluster.spec.networking.auth.oAuthClientName)
-                }
-              }
-            }
-
-            const oauthClients = await kh.listOAuthClientBySelector('app.kubernetes.io/part-of=che.eclipse.org')
-            for (const oauthClient of oauthClients) {
-              await kh.deleteOAuthClient(oauthClient.metadata.name)
-            }
-
-            task.title = `${task.title}...[Ok]`
-          } catch (e: any) {
-            task.title = `${task.title}...[Failed: ${e.message}]`
-          }
-        },
-      },
-      {
-        title: `Delete the Custom Resource of type ${CHE_CLUSTER_CRD}`,
+        title: `Delete ${CHE_CLUSTER_API_GROUP}/${CHE_CLUSTER_API_VERSION_V2} resources`,
         task: async (_ctx: any, task: any) => {
           try {
             await kh.deleteAllCheClusters(flags.chenamespace)
@@ -567,6 +555,26 @@ export class OperatorTasks {
           }
         },
       },
+    ]
+  }
+
+  /**
+   * Returns list of tasks which remove Red Hat OpenShift Dev Spaces operator related resources
+   */
+  getDeleteTasks(flags: any): ReadonlyArray<Listr.ListrTask> {
+    const kh = new KubeHelper(flags)
+    return [
+      {
+        title: `Delete ValidatingWebhookConfiguration ${OperatorTasks.VALIDATING_WEBHOOK}`,
+        task: async (_ctx: any, task: any) => {
+          try {
+            await kh.deleteValidatingWebhookConfiguration(OperatorTasks.VALIDATING_WEBHOOK)
+            task.title = `${task.title}...[Ok]`
+          } catch (e: any) {
+            task.title = `${task.title}...[Failed: ${e.message}]`
+          }
+        },
+      },
       {
         title: 'Delete CRDs',
         task: async (_ctx: any, task: any) => {
@@ -676,16 +684,16 @@ export class OperatorTasks {
 
             const clusterRoleBindings = await kh.listClusterRoleBindings()
             for (const clusterRoleBinding of clusterRoleBindings.items) {
-              const name = clusterRoleBinding.metadata && clusterRoleBinding.metadata.name || ''
-              if (name.startsWith(flags.chenamespace) || name.startsWith(OperatorTasks.DEVWORKSPACE_PREFIX)) {
+              const name = clusterRoleBinding.metadata?.name
+              if (name && name.startsWith(flags.chenamespace)) {
                 await kh.deleteClusterRoleBinding(name)
               }
             }
 
             const clusterRoles = await kh.listClusterRoles()
             for (const clusterRole of clusterRoles.items) {
-              const name = clusterRole.metadata && clusterRole.metadata.name || ''
-              if (name.startsWith(flags.chenamespace) || name.startsWith(OperatorTasks.DEVWORKSPACE_PREFIX)) {
+              const name = clusterRole.metadata?.name
+              if (name && name.startsWith(flags.chenamespace)) {
                 await kh.deleteClusterRole(name)
               }
             }
@@ -753,6 +761,57 @@ export class OperatorTasks {
           }
         },
       },
+      {
+        title: `Delete Issuer ${OperatorTasks.ISSUER}`,
+        task: async (_ctx: any, task: any) => {
+          try {
+            await kh.deleteIssuer(OperatorTasks.ISSUER, this.flags.chenamespace)
+            task.title = `${task.title}...[Ok]`
+          } catch (e: any) {
+            task.title = `${task.title}...[Failed: ${e.message}]`
+          }
+        },
+      },
+      {
+        title: `Delete Certificate ${OperatorTasks.CERTIFICATE}`,
+        task: async (_ctx: any, task: any) => {
+          try {
+            await kh.deleteCertificate(OperatorTasks.CERTIFICATE, this.flags.chenamespace)
+            task.title = `${task.title}...[Ok]`
+          } catch (e: any) {
+            task.title = `${task.title}...[Failed: ${e.message}]`
+          }
+        },
+      },
+      {
+        title: 'Delete OAuthClient',
+        enabled: (ctx: any) => ctx[ChectlContext.IS_OPENSHIFT],
+        task: async (_ctx: any, task: any) => {
+          try {
+            const checluster = await kh.getCheClusterV1(flags.chenamespace)
+            if (checluster) {
+              if (isCheClusterAPIV1(checluster)) {
+                if (checluster?.spec?.auth?.oAuthClientName) {
+                  await kh.deleteOAuthClient(checluster.spec.auth.oAuthClientName)
+                }
+              } else {
+                if (checluster?.spec?.networking?.auth?.oAuthClientName) {
+                  await kh.deleteOAuthClient(checluster.spec.networking.auth.oAuthClientName)
+                }
+              }
+            }
+
+            const oauthClients = await kh.listOAuthClientBySelector('app.kubernetes.io/part-of=che.eclipse.org')
+            for (const oauthClient of oauthClients) {
+              await kh.deleteOAuthClient(oauthClient.metadata.name)
+            }
+
+            task.title = `${task.title}...[Ok]`
+          } catch (e: any) {
+            task.title = `${task.title}...[Failed: ${e.message}]`
+          }
+        },
+      },
       {
         title: 'Delete PVCs',
         task: async (_ctx: any, task: any) => {
@@ -830,8 +889,7 @@ export class OperatorTasks {
     resources.clusterRoles = []
     resources.clusterRoleBindings = []
 
-    const platform = ctx[ChectlContext.IS_OPENSHIFT] ? 'openshift' : 'kubernetes'
-    for (const basePath of [ctx[ChectlContext.RESOURCES], path.join(ctx[ChectlContext.RESOURCES], platform)]) {
+    for (const basePath of [ctx[ChectlContext.RESOURCES], path.join(ctx[ChectlContext.RESOURCES], 'kubernetes')]) {
       if (!fs.existsSync(basePath)) {
         continue
       }
@@ -888,8 +946,7 @@ export class OperatorTasks {
     }
 
     // Platform specific resource
-    const platform = ctx[ChectlContext.IS_OPENSHIFT] ? 'openshift' : 'kubernetes'
-    return path.join(ctx[ChectlContext.RESOURCES], platform, 'crds', 'org.eclipse.che_checlusters.yaml')
+    return path.join(ctx[ChectlContext.RESOURCES], 'kubernetes', 'crds', 'org.eclipse.che_checlusters.yaml')
   }
 
   /**
@@ -897,15 +954,6 @@ export class OperatorTasks {
    */
   private getResourcePath(resourceName: string): string {
     const ctx = ChectlContext.get()
-
-    // legacy path
-    const resourcePath = path.join(ctx[ChectlContext.RESOURCES], resourceName)
-    if (fs.existsSync(resourcePath)) {
-      return resourcePath
-    }
-
-    // Platform specific resource
-    const platform = ctx[ChectlContext.IS_OPENSHIFT] ? 'openshift' : 'kubernetes'
-    return path.join(ctx[ChectlContext.RESOURCES], platform, resourceName)
+    return path.join(ctx[ChectlContext.RESOURCES], 'kubernetes', resourceName)
   }
 }
